@@ -2,6 +2,8 @@ import unittest
 
 import ramda as R
 
+from .helpers.Maybe import Just
+
 """
 https://github.com/ramda/ramda/blob/master/test/difference.js
 """
@@ -22,12 +24,6 @@ class TestDifference(unittest.TestCase):
     self.assertEqual([1, 2], R.difference(M2, N2))
 
   def test_has_R_equals_semantics(self):
-    class Just():
-      def __init__(self, x):
-        self.value = x
-
-      def equals(self, x):
-        return isinstance(x, Just) and R.equals(x.value, self.value)
     # TODO: ignore neg-zero and pos-zero check for now, due to simlicity
     # self.assertEqual(1, len(R.difference([0], [-0])))
     self.assertEqual(0, len(R.difference([float('nan')], [float('nan')])))
